@@ -66,9 +66,6 @@ typedef enum {
         POWER_KEY,
         SUSPEND_KEY,
         HIBERNATE_KEY,
-        SCREEN_BRIGHTNESS_UP_KEY,
-        SCREEN_BRIGHTNESS_DOWN_KEY,
-        SCREEN_BRIGHTNESS_CYCLE_KEY,
         KEYBOARD_BRIGHTNESS_UP_KEY,
         KEYBOARD_BRIGHTNESS_DOWN_KEY,
         KEYBOARD_BRIGHTNESS_TOGGLE_KEY,
