@@ -21,11 +21,11 @@
 
 # pragma once
 
-#include <gio/gio.h>
+#include "gsd-application.h"
 
 G_BEGIN_DECLS
 
 #define GSD_TYPE_WWAN_MANAGER (gsd_wwan_manager_get_type())
-G_DECLARE_FINAL_TYPE (GsdWwanManager, gsd_wwan_manager, GSD, WWAN_MANAGER, GApplication)
+G_DECLARE_FINAL_TYPE (GsdWwanManager, gsd_wwan_manager, GSD, WWAN_MANAGER, GsdApplication)
 
 G_END_DECLS
